@@ -161,7 +161,7 @@
   * OpenBSD 2.4 ptrace() resumes a stopped process when detaching, so we must
   * re-suspend upon detach.
   */
-#if defined(OPENBSD2)
+#if defined(OPENBSD2) || defined(OPENBSD3)
 #define SUPPORTED
 #include <sys/param.h>
 #include <sys/user.h>
@@ -788,7 +788,7 @@ static PROC_INFO *open_process(pid_t pid)
     return (proc);
 #endif
 
-#if defined(OPENBSD2)
+#if defined(OPENBSD2) || defined(OPENBSD3)
     PROC_INFO *proc;
     MAP_INFO *mp;
     struct kinfo_proc *procp;
